@@ -1,4 +1,4 @@
-from notion2md.notion_client import notion_client_object
+from notion2md.client_store import notion_client_object
 from notion2md.convertor.block import blocks_convertor
 import os
 import time
@@ -10,7 +10,7 @@ def block_exporter(config):
     if not os.path.exists(config.output_path):
         os.mkdir(config.output_path)
     #Get actual blocks
-
+    print()
     print_status("Retrieving",f"blocks from '{config.target_id}'")
     blocks = notion_client_object.blocks.children.list(config.target_id)['results']
     #Write(Export) Markdown file
@@ -20,6 +20,7 @@ def block_exporter(config):
     #Result and Time Check
     print_status("Converted", f"{str(len(blocks))} blocks to markdown in {time.time() - start_time:.2f}s")
     print_status("Exported", f'"{config.file_name}.md" in "{os.path.abspath(config.output_path)}/"')
+    print()
 
 # page_exporter()
 
